@@ -28,13 +28,13 @@ def extract_domain_name(url: str) -> str:
     if not netloc:
         return ''
 
-    return public_suffix().get_public_suffix(netloc)
+    return public_suffix().privatesuffix(netloc)
 
 
 @lru_cache(maxsize=None)
 def public_suffix():
     # expensive to import and initialize, so lru_cache
-    from publicsuffix2 import PublicSuffixList
+    from publicsuffixlist import PublicSuffixList
     return PublicSuffixList()
 
 
